@@ -495,6 +495,8 @@ int Preferences::ExplorerShell()
         ".adts;AACFile\r\n"
         ".ac3;AC3File\r\n"
         ".act;WAVFile\r\n"
+        ".aif;AIFFFile\r\n"
+        ".aifc;AIFFFile\r\n"
         ".aiff;AIFFFile\r\n"
         ".amr;AMRFile\r\n"
         ".ape;APEFile\r\n"
@@ -510,6 +512,8 @@ int Preferences::ExplorerShell()
         ".dde;DolbyEFile\r\n"
         ".divx;AVIFile\r\n"
         ".dpg;DPGFile\r\n"
+        ".dff;DFFFile\r\n"
+        ".dsf;DSFFile\r\n"
         ".dts;DTSFile\r\n"
         ".dv;EAC3File\r\n"
         ".dvr;DVRFile\r\n"
@@ -519,6 +523,7 @@ int Preferences::ExplorerShell()
         ".f4a;mpeg4File\r\n"  
         ".f4b;mpeg4File\r\n" 
         ".f4v;mpeg4File\r\n"
+        ".fla;FLACFile\r\n"
         ".flc;FLICFile\r\n"
         ".fli;FLICFile\r\n"
         ".flac;FLACFile\r\n"
@@ -530,6 +535,7 @@ int Preferences::ExplorerShell()
         ".h3d;JPEGFile\r\n"
         ".hdmov;MOVFile\r\n"
         ".ifo;IfoFile\r\n"
+        ".ism;ISMFile\r\n"
         ".isma;ISMAFile\r\n"
         ".ismv;ISMVFile\r\n"
         ".j2k;JPEGFile\r\n"
@@ -577,6 +583,7 @@ int Preferences::ExplorerShell()
         ".ogg;OGGFile\r\n"
         ".ogm;OGMFile\r\n"
         ".ogv;OGVFile\r\n"
+        ".ogx;OGXFile\r\n"
         ".oma;ATRACFile\r\n"
         ".opus;OpusFile\r\n"
         ".png;PNGFile\r\n"
@@ -586,15 +593,17 @@ int Preferences::ExplorerShell()
         ".ra;RMFile\r\n"
         ".rm;RMFile\r\n"
         ".rmvb;FlashVideoFile\r\n"
+        ".shn;ShortenFile\r\n"
         ".smv;SMVFile\r\n"
+        ".spdif;SPDIFFile\r\n"
         ".spx;SpeexFile\r\n"
         ".stl;STLFile\r\n"
         ".swf;FlashFile\r\n"
         ".tak;TakVideoFile\r\n"
         ".thd;THDFile\r\n"
         ".thd+ac3;THDFile\r\n"
-	".tif;TIFFFile\r\n"
-	".tiff;TIFFFile\r\n"
+        ".tif;TIFFFile\r\n"
+        ".tiff;TIFFFile\r\n"
         ".tmf;mpegFile\r\n"
         ".tp;TPFile\r\n"
         ".trp;TRPFile\r\n"
@@ -603,6 +612,7 @@ int Preferences::ExplorerShell()
         ".ty;mpegFile\r\n"
         ".vob;mpegFile\r\n"
         ".vqf;VQFFile\r\n"
+        ".vro;VROFile\r\n"
         ".w64;W64File\r\n"
         ".wav;WAVFile\r\n"
         ".webM;WebMFile\r\n"
@@ -1118,6 +1128,8 @@ int Preferences::ShellToolTip()
         ".dde;DolbyEFile\r\n"
         ".divx;AVIFile\r\n"
         ".dpg;DPGFile\r\n"
+        ".dsf;DFFFile\r\n"
+        ".dsf;DSFFile\r\n"
         ".dts;DTSFile\r\n"
         ".dv;EAC3File\r\n"
         ".dvr;DVRFile\r\n"
@@ -1134,6 +1146,7 @@ int Preferences::ShellToolTip()
         ".h264;H264File\r\n"
         ".hdmov;MOVFile\r\n"
         ".ifo;IfoFile\r\n"
+        ".ism;ISMFile\r\n"
         ".isma;ISMAFile\r\n"
         ".ismv;ISMVFile\r\n"
         ".j2k;JPEGFile\r\n"
@@ -1179,6 +1192,7 @@ int Preferences::ShellToolTip()
         ".ogg;OGGFile\r\n"
         ".ogm;OGMFile\r\n"
         ".ogv;OGVFile\r\n"
+        ".ogx;OGXFile\r\n"
         ".opus;OpusFile\r\n"
         ".png;PNGFile\r\n"
         ".qcp;QCPFile\r\n"
@@ -1190,8 +1204,8 @@ int Preferences::ShellToolTip()
         ".stl;STLFile\r\n"
         ".swf;FlashFile\r\n"
         ".tak;TAKFile\r\n"
-	".tif;TIFFFile\r\n"
-	".tiff;TIFFFile\r\n"
+        ".tif;TIFFFile\r\n"
+        ".tiff;TIFFFile\r\n"
         ".tp;TPFile\r\n"
         ".trp;TRPFile\r\n"
         ".ts;tsFile\r\n"
